pub struct AppContextConfig {
pub vocabulary: Vec<String>,
pub mode: Option<DictationMode>,
}Fields
vocabulary: Vec<String>Vocabulary terms to bias Whisper toward when this app is focused
mode: Option<DictationMode>Dictation mode to use when this app is focused