pub struct SubprocessTranscriber { /* private fields */ }Expand description
A whisper transcriber that runs inference in a child process.
Implementations
Sourceimpl SubprocessTranscriber
impl SubprocessTranscriber
Sourcepub fn new(model_path: &Path, language: &str) -> Result<Self>
pub fn new(model_path: &Path, language: &str) -> Result<Self>
Spawn the worker process with the given model and language.
The worker binary is expected at the same location as the current executable (same target directory).